# Metadata


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**app_name** | **str** | AI application requesting the content scan | [optional] 
**app_user** | **str** | End user using the AI application | [optional] 
**ai_model** | **str** | AI model serving the AI application | [optional] 
**user_ip** | **str** | End user IP using the AI application | [optional] 
**agent_meta** | [**AgentMeta**](AgentMeta.md) |  | [optional] 

## Example

```python
from aisecurity.generated_openapi_client.models.metadata import Metadata

# TODO update the JSON string below
json = "{}"
# create an instance of Metadata from a JSON string
metadata_instance = Metadata.from_json(json)
# print the JSON string representation of the object
print(Metadata.to_json())

# convert the object into a dict
metadata_dict = metadata_instance.to_dict()
# create an instance of Metadata from a dict
metadata_from_dict = Metadata.from_dict(metadata_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


